@@ -116,6 +116,9 @@ SwitchedModes=False
 OfflineMode=False
 PreviousMode="normal"
 SilentProfile=False
+DimmDisplay=False
+PreviousBrightness=5
+RecordingBrightness=0
 PreviousProfile="silent"
 PreviousVolume=50
 
