@@ -49,6 +49,10 @@ def SetAlarm():
         txt=_('Wake up (SleepAnalyser)')
         event.message =str(txt.encode( "utf-8" ))
 
+
+#        now=Tuple2Seconds(time.localtime())
+#        if(now<=records.AlarmTime_seconds):
+#            records.AlarmTime_seconds=now+2
         event.alarm_time = records.AlarmTime_seconds #in seconds
 
         if(data.UseAlternativeAlarm==False): #use normal MAEMO alarm
@@ -74,21 +78,22 @@ def SetAlarm():
         except:
             print "Could not print event data"
 
-        #python-alarm seems to be buggy.
-        #Sometimes it raises randomly the error InvalidEventException
-        #We try to readd it if this happens
-        for i in range(0, 5):
+        #python-alarm seems to through an InvalidEventException error if the alarm time is in the past!
+        for i in range(0, 10):
             print "Try to add alarm event (", i, ")"
             try:
+                print "Alarm time:",  event.alarm_time,  "now:",  Tuple2Seconds(time.localtime())
                 data.AlarmID = alarm.add_event(event) #Try to add alarm event
                 print "AlarmID:", data.AlarmID
                 break #alarm is set, leave loop
             except:
-                print "Could not add alarm event"
-                if(i<4): #give it another try
+                print "Could not add alarm event, might be in the past"
+                records.AlarmTime_seconds =records.AlarmTime_seconds +1 #move it one second ahead in case its already in the past
+                event.alarm_time = records.AlarmTime_seconds #in seconds
+                if(i<9): #give it another try
                     pass
                 else:
-                    print i+1, "trials without success, raise the error about alarm.add_event(event)"
+                    print i+1, "trials without success, raise the error"
                     raise #ok, now really raise the error
 
         print "Ok, could set the alarm"
@@ -109,7 +114,7 @@ def SetAlarm():
 
 
 ###########################################################################
-## Function:    delete_all_preexisting_Alarms
+## Function:    delete_all_Alarms
 ## Description: This function searchs for any SleepAnalyser alarms in the
 ##                MAEMO alarm queue and deletes them
 ##                In case SleepAnalyser crashed during recording, an alarm
@@ -117,7 +122,7 @@ def SetAlarm():
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
-def delete_all_preexisting_Alarms():
+def delete_all_Alarms():
     print "* Search and delete all alarms from SleepAnalyser"
     if(data.DeviceIsN900==True): #We are on a N900
         event = alarm.query_event(0, 0, 0, 0, "") #get list of all set alarm in N900
@@ -279,4 +284,4 @@ def ProcessLucid_Dream(): #Lucid dream option
             data.Lucid_Dream_SongIsActive=True
             records.Lucid_Dream_Song_Start_tuple=time.localtime() #now
             print "Play Lucid dream song"
-            PlaySong(records.Lucid_Dream_Song_Volume, data.Lucid_Dream_Song)
+            PlaySong(records.Lucid_Dream_Song_Volume, records.Lucid_Dream_Song)
