@@ -48,7 +48,7 @@ _ = i18n.language.ugettext
 def LoadPresetNames():
     global PresetNames
     print "Load preset names"
-    
+
     PresetNames = ConfigParser.SafeConfigParser()
     try:
         PresetNames.read(data.configFolder+data.PresetNamesFile)
@@ -67,8 +67,8 @@ def LoadPresetNames():
         except:
             data.preset_names[i]=str(_("Preset")+" "+str(i+1))
             PresetNames.set('main', 'preset'+str(i+1), data.preset_names[i])
-            
-    print data.preset_names
+
+  #  print data.preset_names
 
 
 
@@ -82,11 +82,11 @@ def LoadPresetNames():
 def WritePresetNames():
     global PresetNames
     print "Write preset names"
- 
+
     for i in range(0, 3):
         PresetNames.set('main', 'Preset'+str(i+1),  str(data.preset_names[i].encode( "utf-8" )))
- 
- 
+
+
     f=data.configFolder+data.PresetNamesFile
     if(data.debug==True): print "Save preset names ("+f+")"
     if (not os.path.exists(str(data.configFolder))):
@@ -99,8 +99,8 @@ def WritePresetNames():
         print "Preset names saved"
     except:
         print "Failed to write preset names file!"
-        
-        
+
+
 
 
 
@@ -129,229 +129,63 @@ def LoadConfig():
         pass
 
 
-    try:
-        data.Sampling_interval = config.getint('main', 'sampling')
-    except:
-        config.set('main', 'sampling', str(data.Sampling_interval))
 
-    try:
-        data.Sample_smoothing = config.getint('main', 'sample_smoothing')
-    except:
-        config.set('main', 'sample_smoothing', str(data.Sample_smoothing))
 
-    try:
-        data.Value_smoothing = config.getint('main', 'value_smoothing')
-    except:
-        config.set('main', 'value_smoothing', str(data.Value_smoothing))
+    data.Sampling_interval = Config_Load_Int('main', 'sampling', data.Sampling_interval)
+    data.Sample_smoothing = Config_Load_Int('main', 'Sample_smoothing', data.Sample_smoothing)
+    data.Value_smoothing = Config_Load_Int('main', 'Value_smoothing', data.Value_smoothing)
+    data.Trigger = Config_Load_Int('main', 'Trigger', data.Trigger)
+    data.Derivation = Config_Load_Int('main', 'Derivation', data.Derivation)
+    data.Ysize = Config_Load_Int('main', 'Ysize', data.Ysize)
+    data.Xscale = Config_Load_Int('main', 'Xscale', data.Xscale)
+    data.Yscale_Movement = Config_Load_Int('main', 'Yscale_Movement', data.Yscale_Movement_default)
+    data.derivation_offset = Config_Load_Int('main', 'derivation_offset', data.derivation_offset)
+    data.Yscale_Sleep_Pattern = Config_Load_Int('main', 'Yscale_Sleep_Pattern', data.Yscale_Sleep_Pattern_default)
+    data.Yoffset_Sleep_Pattern = Config_Load_Int('main', 'Yoffset_Sleep_Pattern', data.Yoffset_Sleep_Pattern_default)
+    data.limitMovement = Config_Load_Int('main', 'limitMovement', data.limitMovement)
+    data.DelayStartTime = Config_Load_Int('main', 'DelayStartTime', data.DelayStartTime)
+    data.AlarmHour = Config_Load_Int('main', 'AlarmHour', data.AlarmHour)
+    data.AlarmMinute = Config_Load_Int('main', 'AlarmMinute', data.AlarmMinute)
+    data.AlarmTimeWindow = Config_Load_Int('main', 'AlarmTimeWindow', data.AlarmTimeWindow)
+    data.Lucid_Dream_Song_Volume = Config_Load_Int('main', 'Lucid_Dream_Song_Volume', data.Lucid_Dream_Song_Volume)
+    data.Lucid_Dream_Song_Delay = Config_Load_Int('main', 'Lucid_Dream_Song_Delay', data.Lucid_Dream_Song_Delay)
+    data.Lucid_Dream_Song_Duration = Config_Load_Int('main', 'Lucid_Dream_Song_Duration', data.Lucid_Dream_Song_Duration)
+    data.WakeUp_Song_Volume_Increase_Step = Config_Load_Int('main', 'WakeUp_Song_Volume_Increase_Step', data.WakeUp_Song_Volume_Increase_Step)
+    data.WakeUp_Song_Volume = Config_Load_Int('main', 'WakeUp_Song_Volume', data.WakeUp_Song_Volume)
+    data.WakeUp_Song_Duration = Config_Load_Int('main', 'WakeUp_Song_Duration', data.WakeUp_Song_Duration)
+    data.Light_Sleep_Level = Config_Load_Int('main', 'Light_Sleep_Level', data.Light_Sleep_Level_default)
+    data.Deep_Sleep_Level = Config_Load_Int('main', 'Deep_Sleep_Level', data.Deep_Sleep_Level_default)
 
-    try:
-        data.Trigger = config.getint('main', 'Trigger')
-    except:
-        config.set('main', 'Trigger', str(data.Trigger))
-
-    try:
-        data.Derivation = config.getint('main', 'Derivation')
-    except:
-        config.set('main', 'Derivation', str(data.Derivation))
-
-    try:
-        data.Ysize = config.getint('main', 'Ysize')
-    except:
-        config.set('main', 'Ysize', str(data.Ysize))
-
-    try:
-        data.Xscale = config.getint('main', 'Xscale')
-    except:
-        config.set('main', 'Xscale', str(data.Xscale))
-
-    try:
-        data.Yscale_Movement = config.getint('main', 'Yscale_Movement')
-    except:
-        data.Yscale_Movement=data.Yscale_Movement_default
-        config.set('main', 'Yscale_Movement', str(data.Yscale_Movement))
-
-    try:
-        data.derivation_offset = config.getint('main', 'derivation_offset')
-    except:
-        config.set('main', 'derivation_offset', str(data.derivation_offset))
-
-    try:
-        data.Yscale_Sleep_Pattern = config.getint('main', 'Yscale_Sleep_Pattern')
-    except:
-        data.Yscale_Sleep_Pattern=data.Yscale_Sleep_Pattern_default
-        config.set('main', 'Yscale_Sleep_Pattern', str(data.Yscale_Sleep_Pattern))
-
-    try:
-        data.Yoffset_Sleep_Pattern = config.getint('main', 'Yoffset_Sleep_Pattern')
-    except:
-        data.Yoffset_Sleep_Pattern=data.Yoffset_Sleep_Pattern_default
-        config.set('main', 'Yoffset_Sleep_Pattern', str(data.Yoffset_Sleep_Pattern))
-
-    try:
-        data.limitMovement = config.getint('main', 'limitMovement')
-    except:
-        config.set('main', 'limitMovement', str(data.limitMovement))
 
+#    data.user = Config_Load_String('main', 'user', data.user)
     try:
         tmp=config.get('main', 'user')
         data.user = tmp.decode("utf-8")
     except:
         config.set('main', 'user', str(data.user.encode( "utf-8" )))
 
-    try:
-        data.LastRecord = config.get('main', 'LastRecord')
-    except:
-        config.set('main', 'LastRecord', str(data.LastRecord))
-
-    try:
-        tmp = config.get('main', 'OfflineMode')
-        if(tmp=="True"): data.OfflineMode=True
-        else: data.OfflineMode=False
-    except:
-        config.set('main', 'OfflineMode', str(data.OfflineMode))
-
-    try:
-        tmp = config.get('main', 'SilentProfile')
-        if(tmp=="True"): data.SilentProfile=True
-        else: data.SilentProfile=False
-    except:
-        config.set('main', 'SilentProfile', str(data.SilentProfile))
-
-    try:
-        data.DelayStartTime = config.getint('main', 'DelayStartTime')
-    except:
-        config.set('main', 'DelayStartTime', str(data.DelayStartTime))
-
-    try:
-        tmp = config.get('main', 'UseAlarm')
-        if(tmp=="True"): data.UseAlarm=True
-        else: data.UseAlarm=False
-    except:
-        config.set('main', 'UseAlarm', str(data.UseAlarm))
-
-    try:
-        data.AlarmHour = config.getint('main', 'AlarmHour')
-    except:
-        config.set('main', 'AlarmHour', str(data.AlarmHour))
-
-    try:
-        data.AlarmMinute = config.getint('main', 'AlarmMinute')
-    except:
-        config.set('main', 'AlarmMinute', str(data.AlarmMinute))
-
-    try:
-        data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
-    except:
-        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))
-
-    try:
-        tmp = config.get('main', 'StopAfterAlarm')
-        if(tmp=="True"): data.StopAfterAlarm=True
-        else: data.StopAfterAlarm=False
-    except:
-        config.set('main', 'StopAfterAlarm', str(data.StopAfterAlarm))
+    data.LastRecord = Config_Load_String('main', 'LastRecord', data.LastRecord)
+    data.AlternativeAlarm = Config_Load_String('main', 'AlternativeAlarm', data.AlternativeAlarm)
+    data.Lucid_Dream_Song = Config_Load_String('main', 'Lucid_Dream_Song', data.Lucid_Dream_Song)
+    data.WakeUp_Song = Config_Load_String('main', 'WakeUp_Song', data.WakeUp_Song)
+    data.cliStart = Config_Load_String('main', 'cliStart', data.cliStart)
+    data.cliStop = Config_Load_String('main', 'cliStop', data.cliStop)
 
 
-
-    try:
-        tmp = config.get('main', 'Use_Lucid_Dream_Song')
-        if(tmp=="True"): data.Use_Lucid_Dream_Song=True
-        else: data.Use_Lucid_Dream_Song=False
-    except:
-        config.set('main', 'Use_WakeUp_Song', str(data.Use_WakeUp_Song))
-
-    try:
-        data.Lucid_Dream_Song = config.get('main', 'Lucid_Dream_Song')
-    except:
-        config.set('main', 'Lucid_Dream_Song', str(data.Lucid_Dream_Song))
-
-    try:
-        data.Lucid_Dream_Song_Volume = config.getint('main', 'Lucid_Dream_Song_Volume')
-    except:
-        config.set('main', 'Lucid_Dream_Song_Volume', str(data.Lucid_Dream_Song_Volume))
-
-    try:
-        data.Lucid_Dream_Song_Delay = config.getint('main', 'Lucid_Dream_Song_Delay')
-    except:
-        config.set('main', 'Lucid_Dream_Song_Delay', str(data.Lucid_Dream_Song_Delay))
-
-    try:
-        data.Lucid_Dream_Song_Duration = config.getint('main', 'Lucid_Dream_Song_Duration')
-    except:
-        config.set('main', 'Lucid_Dream_Song_Duration', str(data.Lucid_Dream_Song_Duration))
+    data.OfflineMode = Config_Load_Bool('main', 'OfflineMode', data.OfflineMode)
+    data.SilentProfile = Config_Load_Bool('main', 'SilentProfile', data.SilentProfile)
+    data.DimmDisplay = Config_Load_Bool('main', 'DimmDisplay', data.DimmDisplay)
+    data.UseAlarm = Config_Load_Bool('main', 'UseAlarm', data.UseAlarm)
+    data.StopAfterAlarm = Config_Load_Bool('main', 'StopAfterAlarm', data.StopAfterAlarm)
+    data.Use_Lucid_Dream_Song = Config_Load_Bool('main', 'Use_Lucid_Dream_Song', data.Use_Lucid_Dream_Song)
+    data.Use_WakeUp_Song = Config_Load_Bool('main', 'Use_WakeUp_Song', data.Use_WakeUp_Song)
+    data.UseAlternativeAlarm = Config_Load_Bool('main', 'UseAlternativeAlarm', data.UseAlternativeAlarm)
 
 
 
-    try:
-        tmp = config.get('main', 'Use_WakeUp_Song')
-        if(tmp=="True"): data.Use_WakeUp_Song=True
-        else: data.Use_WakeUp_Song=False
-    except:
-        config.set('main', 'Use_WakeUp_Song', str(data.Use_WakeUp_Song))
-
-    try:
-        data.WakeUp_Song = config.get('main', 'WakeUp_Song')
-    except:
-        config.set('main', 'WakeUp_Song', str(data.WakeUp_Song))
-
-    try:
-        data.WakeUp_Song_Volume = config.getint('main', 'WakeUp_Song_Volume')
-    except:
-        config.set('main', 'WakeUp_Song_Volume', str(data.WakeUp_Song_Volume))
-
-    try:
-        data.WakeUp_Song_Volume_Increase_Step = config.getint('main', 'WakeUp_Song_Volume_Increase_Step')
-    except:
-        config.set('main', 'WakeUp_Song_Volume_Increase_Step', str(data.WakeUp_Song_Volume_Increase_Step))
-
-    try:
-        data.WakeUp_Song_Duration = config.getint('main', 'WakeUp_Song_Duration')
-    except:
-        config.set('main', 'WakeUp_Song_Duration', str(data.WakeUp_Song_Duration))
-
-
-    try:
-        data.AlternativeAlarm = config.get('main', 'AlternativeAlarm')
-    except:
-        config.set('main', 'AlternativeAlarm', str(data.AlternativeAlarm))
-
-    try:
-        tmp = config.get('main', 'UseAlternativeAlarm')
-        if(tmp=="True"): data.UseAlternativeAlarm=True
-        else: data.UseAlternativeAlarm=False
-    except:
-        config.set('main', 'UseAlternativeAlarm', str(data.UseAlternativeAlarm))
-
-    try:
-        data.cliStart = config.get('main', 'cliStart')
-    except:
-        config.set('main', 'cliStart', "")
-
-    try:
-        data.cliStop = config.get('main', 'cliStop')
-    except:
-        config.set('main', 'clisStop', "")
-
-
-
-    try:
-        data.Light_Sleep_Level = config.getint('main', 'Light_Sleep_Level')
-    except:
-        data.Light_Sleep_Level=data.Light_Sleep_Level_default
-        config.set('main', 'Light_Sleep_Level', str(data.Light_Sleep_Level))
-
-    try:
-        data.Deep_Sleep_Level = config.getint('main', 'Deep_Sleep_Level')
-    except:
-        data.Deep_Sleep_Level=data.Deep_Sleep_Level_default
-        config.set('main', 'Deep_Sleep_Level', str(data.Deep_Sleep_Level))
-
 
 ## Add forced configuration changes here
-    try:
-        configFileVersion = config.getint('main', 'configFileVersion')
-    except:
-        configFileVersion=0
+    configFileVersion = Config_Load_Int('main', 'configFileVersion', 0)
     if(configFileVersion<data.configFileVersion): #config file is old, update some parameters...
         if(data.configFileVersion<=3):
             data.Yscale_Movement=data.Yscale_Movement_default
@@ -374,6 +208,63 @@ def LoadConfig():
 
 
 
+
+###########################################################################
+## Function:    Config_Load_String
+## Description: Loads a string from the configuration. Uses default value in case econfig ntry does not exist
+## Parameters:  section,  entry,  default
+## Returns:     value
+###########################################################################
+def Config_Load_String(section,  entry,  default):
+    try:
+ #       return (config.get(section, entry)).decode("utf-8")
+        return (config.get(section, entry))
+    except:
+        config.set(section, entry, str(default))
+#        config.set(section, entry, str(default.encode( "utf-8" )))
+        return str(default)
+
+
+
+
+
+
+###########################################################################
+## Function:    Config_Load_Bool
+## Description: Loads a bool value from the configuration. Uses default value in case econfig ntry does not exist
+## Parameters:  section,  entry,  default
+## Returns:     value
+###########################################################################
+def Config_Load_Bool(section,  entry,  default):
+    try:
+        tmp=config.get(section, entry)
+        if(tmp=="True"):  return True
+        else: return False
+    except:
+        config.set(section, entry, str(default))
+        return default
+
+
+
+
+
+###########################################################################
+## Function:    Config_Load_Int
+## Description: Loads an integer from the configuration. Uses default value in case econfig ntry does not exist
+## Parameters:  section,  entry,  default
+## Returns:     value
+###########################################################################
+def Config_Load_Int(section,  entry,  default):
+    try:
+        return config.getint(section, entry)
+    except:
+        config.set(section, entry, str(default))
+        return int(default)
+
+
+
+
+
 ###########################################################################
 ## Function:    WriteConfig
 ## Description: This function loads the config into the config file
@@ -501,6 +392,9 @@ def SwitchModes(start):
                         set_silent(True)
                     data.PreviousVolume=GetVolume()
 
+                    if(data.DimmDisplay==True): #dimm display brightness
+                        SetBrightness(data.RecordingBrightness)
+
                     if(data.cliStart!=""):
                         cmd=data.cliStart+" &" #Expert option to run a script at recording start
                         print "### Run command: ", cmd
@@ -633,6 +527,44 @@ def GetVolume():
 
 
 
+
+
+
+###########################################################################
+## Function:    GetBrightness
+## Description: Get display brightness, store it in data.PreviousBrightness
+## Parameters:  none
+## Returns:     none
+###########################################################################
+def GetBrightness():
+    if(data.DeviceIsN900==True): #we are on a N900
+ #       output = os.popen("cat /sys/class/backlight/acx565akm/brightness").read() # run cmd and make the output look like a file I can read
+        output = os.popen("gconftool -g /system/osso/dsm/display/display_brightness").read() # run cmd and make the output look like a file I can read
+        data.PreviousBrightness=int(output)
+        print "Get current brightness level:", data.PreviousBrightness
+
+
+
+
+###########################################################################
+## Function:    SetBrightness
+## Description: Set display brightness
+## Parameters:  brigntness level (1..5)
+## Returns:     none
+###########################################################################
+def SetBrightness(b):
+    if(data.DeviceIsN900==True): #we are on a N900
+        print "Set brightness level :", b
+ #       cmd="echo "+ str(b)+" > /sys/class/backlight/acx565akm/brightness"
+        cmd ="gconftool -s /system/osso/dsm/display/display_brightness -t int "+str(b)
+        b = os.popen(cmd)
+        b.close()
+
+
+
+
+
+
 ###########################################################################
 ## Function:    Notify
 ## Description: Shows a notification message
@@ -656,7 +588,7 @@ def getFileList(path,  filter):
     output = os.popen("cd \""+str(path)+"\"; ls -C1 "+str(filter)).read() # run ls and make the output look like a file I can read
     #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
     arr=output.split("\n")
-    arr.pop()   
+    arr.pop()
     return arr
 
 
@@ -714,6 +646,7 @@ def GetSongLength(filename):
     except:
         duration=300 #set to 5 minutes
         print "ERROR: Could not get song length!"
+        print "Set to default 5 minutes"
     return duration
 
 
