@@ -38,7 +38,6 @@ DEFAULT_LANGUAGES = os.environ.get('LANG', '').split(':')
 DEFAULT_LANGUAGES += ['en_US']
 if(data.debug==True): print "Languages:", DEFAULT_LANGUAGES
 
-
 # Try to get the languages from the default locale
 if(data.language==""):
     lc, encoding = locale.getdefaultlocale()
@@ -53,12 +52,17 @@ else:
     languages=[data.language]
     print "Locale:", data.language
 
-
 # Concat all languages (env + default locale),
 #  and here we have the languages and location of the translations
 languages += DEFAULT_LANGUAGES
+
 mo_location = LOCALE_DIR
 
+if(data.language!=""):
+    languages[1]=data.language+".UTF-8" #Workaround to get "en" as parameter working
+
+print languages
+
 # Lets tell those details to gettext
 #  (nothing to change here for you)
 gettext.install (True,localedir=None, unicode=1)
